### About
A package to ease the control of the [blinkstick nano](https://www.blinkstick.com/products/blinkstick-nano)

Source code is at [https://github.com/weshouman/advanced_led_control](https://github.com/weshouman/advanced_led_control)

